<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Empty::Internal::EmptyPlugin</name>
    <message>
        <location filename="../../plugins/emptyplugin/emptyplugin.cpp" line="97"/>
        <source>Initializing emptyplugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
